@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,8 +17,10 @@
 
 int main(int argc, char *argv[])
 {
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
     QApplication app(argc, argv);
     app.setDesktopFileName(QStringLiteral("org.kde.mboximporter"));
     KCrash::initialize();
@@ -29,7 +31,7 @@ int main(int argc, char *argv[])
                          QStringLiteral(MBOXIMPORTER_VERSION),
                          i18n("MBox Import Tool"),
                          KAboutLicense::GPL_V2,
-                         i18n("Copyright © 2013-2021 MBoxImporter authors"));
+                         i18n("Copyright © 2013-%1 MBoxImporter authors", QStringLiteral("2022")));
     aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
 
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kmail")));
@@ -56,7 +58,7 @@ int main(int argc, char *argv[])
     if (fileName.isEmpty()) {
         return 0;
     }
-    auto *w = new MBoxMainWindow(fileName);
+    auto w = new MBoxMainWindow(fileName);
     w->show();
     QObject::connect(w, &MBoxMainWindow::rejected, &app, &QApplication::quit);
     const int ret = app.exec();
